pub struct Claim<F: PrimeField, C: Commitment<F>> {
pub c: C,
pub x: F,
pub y: F,
}Expand description
A tuple (c, x, y) of the form (G, F, F). Represents a claim that {f(x) = y, for a polynomial f such that commit(f) = c}. In other words, it is am instance in some language of “correct polynomial evaluations”. Soundness properties of a claim are defined by that of the argument.
Fields
c: Cx: Fy: FImplementations